Getting help using pyAFQ
~~~~~~~~~~~~~~~~~~~~~~~~

If you run into any bugs or issues using pyAFQ, please contact us using
one of the following communication channels:

#. You can post an issue on our GitHub repository by going to this
   `page <https://github.com/yeatmanlab/pyAFQ/issues>`_ and clicking on the "new
   issue" button. Please provide all pertinent information about the issue you
   are facing: we often need to know what version of the software you are
   running and how you installed it, as well as the operating system that you
   are using. If you run into issues with your data, we might ask you to share a
   small sample of your data with us, so that we can examine it. Please make
   sure that your study ethics procedure allows you to share this data before
   sending it on to us.

#. Questions regarding the method and its use can also be posted to the
   `Neurostars <https://neurostars.org/>`_ Q&A forum.